package org.greenstone.gatherer.gui;

import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import org.greenstone.gatherer.Dictionary;
import org.greenstone.gatherer.Gatherer;
import org.greenstone.gatherer.file.FileNode;

public class NewFolderPrompt
    extends JDialog 
    implements ActionListener {
    private FileNode node;
    private JButton cancel_button;
    private JButton ok_button;
    private JTextField name_field;
    private String name;
    static final private Dimension LABEL_SIZE = new Dimension(150,25);
    static final private Dimension SIZE = new Dimension(350,115);

    public NewFolderPrompt(FileNode node) {
	super(Gatherer.g_man, Dictionary.get("NewFolderPrompt.Title"), true);
	this.node = node;
    }

    public void actionPerformed(ActionEvent event) {
	if (event.getSource() == ok_button) {
	    name = name_field.getText();
	}
	else if(event.getSource() == cancel_button) {
	    name = null;
	}
	dispose();
    }

    public String display() {
	setSize(SIZE);
	JPanel content_pane = (JPanel) getContentPane();

	JPanel destination_pane = new JPanel();
	JLabel destination_label = new JLabel();
	destination_label.setPreferredSize(LABEL_SIZE);
	Dictionary.setText(destination_label, "NewFolderPrompt.Destination_Name");
	JTextField destination_textfield = new JTextField(node.getFile().getName());
	destination_textfield.setBackground(Gatherer.config.getColor("coloring.collection_tree_background", false));
	destination_textfield.setEditable(false);
	
	JPanel name_pane = new JPanel();
	JLabel name_label = new JLabel();
	name_label.setPreferredSize(LABEL_SIZE);
	Dictionary.setText(name_label, "NewFolderPrompt.Folder_Name");
	name_field = new JTextField(getAutomaticName());
	Dictionary.setTooltip(name_field, "NewFolderPrompt.Folder_Name_Tooltip");

	JPanel button_pane = new JPanel();
	ok_button = new JButton();
	Dictionary.setBoth(ok_button, "General.OK", "General.OK_Tooltip");
	cancel_button = new JButton();
	Dictionary.setBoth(cancel_button, "General.Cancel", "General.Pure_Cancel_Tooltip");

	// Connection
	cancel_button.addActionListener(this);
	ok_button.addActionListener(this);

	// Layout
	destination_pane.setLayout(new BorderLayout());
	destination_pane.add(destination_label, BorderLayout.WEST);
	destination_pane.add(destination_textfield, BorderLayout.CENTER);

	name_pane.setBorder(BorderFactory.createEmptyBorder(2,0,0,0));
	name_pane.setLayout(new BorderLayout());
	name_pane.add(name_label, BorderLayout.WEST);
	name_pane.add(name_field, BorderLayout.CENTER);

	button_pane.setBorder(BorderFactory.createEmptyBorder(5,0,0,0));
	button_pane.setLayout(new GridLayout(1,2,0,5));
	button_pane.add(ok_button);
	button_pane.add(cancel_button);

	content_pane.setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
	content_pane.setLayout(new BorderLayout());
	content_pane.add(destination_pane, BorderLayout.NORTH);
	content_pane.add(name_pane, BorderLayout.CENTER);
	content_pane.add(button_pane, BorderLayout.SOUTH);

	// Display
	Rectangle frame_bounds = Gatherer.g_man.getBounds();
	setLocation(frame_bounds.x + (frame_bounds.width - SIZE.width) / 2, frame_bounds.y + (frame_bounds.height - SIZE.height) / 2);
	show();
	return name;
    }

    private String getAutomaticName()
    {
	File file = node.getFile();
	String default_name = Dictionary.get("NewFolderPrompt.Default_Folder_Name");
	File temp_file = new File(file, default_name);
	int count = 1;
	while (temp_file.exists()) {
	    temp_file = new File(file, default_name + " " + count);
	    count++;
	}
	return temp_file.getName();
    }
}
